@@ -61,6 +61,10 @@ class Command(BaseCommand):
                         project_stage = ProjectStage.objects.get(import_id=int(row.stage_id))
                     except:
                         project_stage = None
+                    try:
+                        project_date = make_aware(row.job_date)
+                    except:
+                        project_date = None
 
                     company, created = Company.objects.update_or_create(name=settings.PROJECT_CENTER_DEFAULT_COMPANY_NAME)
                     project, created = Project.objects.update_or_create(
@@ -68,6 +72,7 @@ class Command(BaseCommand):
                     defaults={
                         'title':row.project_title,
                         'slug':'{slug}-{project_id}'.format(slug=slugify(row.project_title), project_id=row.project_id),
+                        'date':project_date,
                         'code':row.project_code,
                         'internal':row.is_internal,
                         'category': project_category,
@@ -92,8 +97,10 @@ class Command(BaseCommand):
                         project=project,
                         limit=None)
                     assigned_users = self.import_project_assigned_users(engine=engine, project=project, limit=None)
-                    print(assigned_users)
-                    print('Project ' + project.title + ' import complete. Activities imported:' + str(len(activities)) + '.')
+                    print('Project {title} import complete. Activities: {num_activities}. Users: {num_users}'.format(
+                        title=project.title,
+                        num_users=str(len(assigned_users)),
+                        num_activities=str(len(activities))))
 
     def import_project_categories(self, engine, file):
         with engine.connect() as conn:
@@ -104,7 +111,8 @@ class Command(BaseCommand):
                     category, created = ProjectCategory.objects.update_or_create(
                         import_id=int(row.category_id),
                     defaults={
-                        'name':row.category_name
+                        'name':row.category_name,
+                        'display':row.category_enabled,
                     })
 
     def import_project_status(self, engine, file):
@@ -116,7 +124,8 @@ class Command(BaseCommand):
                     status, created = ProjectStatus.objects.update_or_create(
                         import_id=int(row.status_id),
                     defaults={
-                        'name':row.status_name
+                        'name':row.status_name,
+                        'display': row.status_enabled,
                     })
 
 
@@ -129,7 +138,8 @@ class Command(BaseCommand):
                     status, created = ProjectStage.objects.update_or_create(
                         import_id=int(row.stage_id),
                     defaults={
-                        'name':row.stage_name
+                        'name':row.stage_name,
+                        'display':row.stage_enabled,
                     })
 
     def import_project_users(self, engine, file):
@@ -192,16 +202,18 @@ class Command(BaseCommand):
                     'ss_users.last_name, ' \
                     'ssm_commdep_projects_users.is_owner '.format(project_id=project.import_id)
             result = conn.execute(text(query))
+            users = []
             for row in result:
                 try:
                     user = User.objects.get(
                         import_id=int(row.user_id)
                     )
-                    print(user)
+                    users.append(user)
                     project.users.add(user)
-                    project.save()
-                except:
+                except Exception as e:
                     pass
+            project.save()
+            return users
 
 
     def import_project_activities(self, engine, file, project=None, limit=None):
@@ -239,6 +251,7 @@ class Command(BaseCommand):
                         'project':project,
                         'date':activity_date,
                         'user':User.objects.get(import_id=row.creator_id),
+                        'notes':row.notes,
                     })
                     activity._change_reason = activity.name
                     activity.save()
